@@ -37,8 +37,12 @@ CDasherView::CDasherView(CEventHandler *pEventHandler, CSettingsStore *pSettings
 void CDasherView::HandleEvent(Dasher::CEvent *pEvent) {
   if(pEvent->m_iEventType == 1) {
     Dasher::CParameterNotificationEvent * pEvt(static_cast < Dasher::CParameterNotificationEvent * >(pEvent));
+    
     switch (pEvt->m_iParameter) {
-    default:
+        case BP_DASHER_PAUSED:  
+	
+                  break;    
+	default:
       break;
     }
   }
@@ -54,7 +58,9 @@ void CDasherView::ChangeScreen(CDasherScreen *NewScreen) {
 
 bool CDasherView::Render(CDasherNode *pRoot, myint iRootMin, myint iRootMax, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, bool bRedrawDisplay, bool bGameMode) {
 
+  m_iRenderCount = 0;
   myint iGamePointer;
+  Screen()->SetLoadBackground(false);
   RenderNodes(pRoot, iRootMin, iRootMax, vNodeList, vDeleteList, &iGamePointer);
 
   if(bGameMode)
@@ -71,7 +77,7 @@ int CDasherView::GetCoordinateCount() {
     return 0;
 }
 
-int CDasherView::GetCoordinates(int iN, myint * pCoordinates) {
+int CDasherView::GetInputCoordinates(int iN, myint * pCoordinates) {
   if(m_pInput)
     return m_pInput->GetCoordinates(iN, pCoordinates);
   else
@@ -101,6 +107,8 @@ void CDasherView::SetInput(CDasherInput * _pInput) {
 }
 
 void CDasherView::Display() {
+  
+  Screen()->SetLoadBackground(true);
   m_pScreen->Display();
 }
 
@@ -117,7 +125,7 @@ void CDasherView::DasherPolyline(myint *x, myint *y, int n, int iWidth, int iCol
     Screen()->Polyline(ScreenPoints, n, iWidth, iColour);
   }
   else {
-    Screen()->Polyline(ScreenPoints, n, iWidth);
+    Screen()->Polyline(ScreenPoints, n, iWidth,0);//no color given
   }
   delete[]ScreenPoints;
 }
