@@ -47,7 +47,7 @@ namespace Dasher {
 /// mode). We should probably consider creating separate classes for
 /// these.
 
-class Dasher::CDasherView:public CDasherComponent
+class Dasher::CDasherView : public Dasher::CDasherComponent
 {
 public:
 
@@ -75,20 +75,20 @@ public:
 
 /*   virtual void Render(CDasherNode *pRoot, myint iRootMin, myint iRootMax, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList); */
 
-  /// Renders Dasher with mouse-dependent items
-  /// \todo Clarify relationship between Render functions and probably only expose one
-
-  virtual bool Render(CDasherNode *pRoot, myint iRootMin, myint iRootMax, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, bool bRedrawDisplay);
-
   /// Renders the Dasher node structure
   /// \todo Shouldn't be public?
 
-  virtual void RenderNodes(CDasherNode *pRoot, myint iRootMin, myint iRootMax, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList) = 0;
+  virtual void RenderNodes(CDasherNode *pRoot, myint iRootMin, myint iRootMax, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, myint *iGamePointer) = 0;
 
   /// Translates the screen coordinates to Dasher coordinates and calls
   /// dashermodel.TapOnDisplay
 
-  virtual void TapOnDisplay(screenint mousex, screenint mousey, unsigned long Time, myint &iDasherX, myint &iDasherY, VECTOR_SYMBOL_PROB* pAdded = NULL, int* pNumDeleted = NULL)=0;
+  virtual int GetCoordinates(unsigned long Time, myint &iDasherX, myint &iDasherY) = 0;
+
+  /// 
+  /// @name Coordinate system conversion
+  /// Convert between screen and Dasher coordinates
+  /// @{
 
   /// 
   /// Convert a screen co-ordinate to Dasher co-ordinates
@@ -102,31 +102,29 @@ public:
 
   virtual void Dasher2Screen(myint iDasherX, myint iDasherY, screenint & iScreenX, screenint & iScreenY) = 0;
 
-  ///
-  /// Convert input device position to Dasher co-ordinates
-  ///
-
-  virtual void Input2Dasher(screenint iInputX, screenint iInputY, myint & iDasherX, myint & iDasherY, int iType, int iMode) = 0;
+  /// @}
 
   /// Change the screen - must be called if the Screen is replaced or resized
   /// \param NewScreen Pointer to the new CDasherScreen.
 
   virtual void ChangeScreen(CDasherScreen * NewScreen);
 
-  /// Get autocallibration offset
-  /// \retval Current offset
+  /// @name High level drawing
+  /// Drawing more complex structures, generally implemented by derived class
+  /// @{
 
-  virtual int GetAutoOffset() const {
-    return 0;
-  }
-/*   ////// \todo Document this */
-/*   virtual void DrawGoTo(screenint mousex, screenint mousey) = 0; */
+  /// Renders Dasher with mouse-dependent items
+  /// \todo Clarify relationship between Render functions and probably only expose one
 
-   virtual void NewDrawGoTo(myint iDasherMin, myint iDasherMax, bool bActive) = 0;
+  virtual bool Render(CDasherNode *pRoot, myint iRootMin, myint iRootMax, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, bool bRedrawDisplay, bool bGameMode);
+
+  virtual void NewDrawGoTo(myint iDasherMin, myint iDasherMax, bool bActive) = 0;
 
   /// Draw the game mode pointer - this shouldn't be here
 
-  virtual void DrawGameModePointer() = 0;
+  virtual void DrawGameModePointer(myint iPosition) = 0;
+
+  /// @}
 
   ////// Return a reference to the screen
   
@@ -139,32 +137,22 @@ public:
 
   void Display();
 
-  /// \todo Document this
-
-  virtual void ResetSum() {
-  }
-
-  /// \todo Document this
-
-  virtual void ResetSumCounter() {
-  }
-
-  /// \todo Document this
-
-  virtual void ResetYAutoOffset() {
-  }
-
   /// Set the input device class. Note that this class will now assume ownership of the pointer, ie it will delete the object when it's done with it.
   /// \param _pInput Pointer to the new CDasherInput.
 
   void SetInput(CDasherInput * _pInput);
 
 
-  virtual void SpeedControl(myint iDasherX, myint iDasherY, double dFrameRate) {};
+  //  virtual void SpeedControl(myint iDasherX, myint iDasherY, double dFrameRate) {};
 
   virtual double xmap(double x) const {return 0.0;};   
   virtual double ymap(double x) const {return 0.0;}; 
 
+  ///
+  /// @name Low level drawing
+  /// Basic drawing primitives specified in Dasher coordinates.
+  /// @{
+
   ///
   /// Draw a polyline specified in Dasher co-ordinates
   ///
@@ -195,28 +183,33 @@ public:
 
   void DasherDrawText(myint iAnchorX1, myint iAnchorY1, myint iAnchorX2, myint iAnchorY2, const std::string & sDisplayText, int &mostleft, bool bShove);
 
+  /// @}
 
   virtual void VisibleRegion( myint &iDasherMinX, myint &iDasherMinY, myint &iDasherMaxX, myint &iDasherMaxY ) = 0;
 
   /// Get the co-ordinates from the input device
   /// \todo This shouldn't be public?
   
-  int GetCoordinates(int iN, myint * pCoordinates); 
+  int GetInputCoordinates(int iN, myint * pCoordinates); 
   
   /// Get the co-ordinate count from the input device
   
   int GetCoordinateCount();
 
+  int GetRenderCount() {
+    return m_iRenderCount;
+  };
 
 protected:
   // Orientation of Dasher Screen
   inline void MapScreen(screenint * DrawX, screenint * DrawY);
   inline void UnMapScreen(screenint * DrawX, screenint * DrawY);
   bool m_bVisibleRegionValid;
- 
- 
+  
   CDelayedDraw *m_pDelayDraw;
 
+  int m_iRenderCount;
+
 private:
   CDasherScreen *m_pScreen;    // provides the graphics (text, lines, rectangles):
   CDasherInput *m_pInput;       // Input device abstraction
