@@ -12,6 +12,14 @@ namespace Dasher {
   
   class CNodeManager {
   public:
+    CNodeManager(int iID) {
+      m_iID = iID;
+    };
+
+    virtual int GetID() {
+      return m_iID;
+    };
+    
     ///
     /// Increment reference count
     ///
@@ -28,6 +36,7 @@ namespace Dasher {
     /// Get a new root node owned by this manager
     ///
 
+    // TODO: What is the point of the pUserData parameter - the node manager should replace it with its own stuff, surely?
     virtual CDasherNode *GetRoot(CDasherNode *pParent, int iLower, int iUpper, void *pUserData) = 0;
 
     ///
@@ -56,6 +65,11 @@ namespace Dasher {
     virtual CDasherNode *RebuildParent(CDasherNode *pNode, int iGeneration) {
       return 0;
     }
+
+    virtual void SetFlag(CDasherNode *pNode, int iFlag, bool bValue) {};
+
+  private:
+    int m_iID;
   };
 
 }
