@@ -1,9 +1,16 @@
 #ifndef __dashercontrol_h__
 #define __dashercontrol_h__
 
+#include "../../config.h"
+
 #include "PangoCache.h"
 #include "Canvas.h"
 #include "../DasherCore/SocketInput.h"
+
+#ifdef JOYSTICK
+#include "joystick_input.h"
+#endif 
+
 #include "mouse_input.h"
 
 #include "GtkDasherControl.h"
@@ -91,30 +98,11 @@ public:
   void CanvasDestroyEvent();
   
   ///
-  /// Key press event on the canvas or the speed slider. This is
-  /// currently a single handler for the two objects, but it may be
-  /// sensible to at least partially split it in the future.
-  /// \todo There's quite a bit of functionality which used to be here in 3.2
-  /// but which has now been removed. Some of this is obsolete button Dasher
-  /// code, but some of it performs useful functions such as recalibration,
-  /// so this needs to be re-implemented.
+  /// Key press event on the canvas
   ///
   
- gint KeyReleaseEvent(GdkEventKey * event);
- gint KeyPressEvent(GdkEventKey * event);
-
-
-  /// 
-  /// \todo Pointless one-line function, bring in to scan_alphabet_files.
-  ///
-
-  int alphabet_filter(const gchar * filename, GPatternSpec * alphabet);
-
-  ///
-  /// \todo Pointless one-line function, bring in to scan_colour_files.
-  ///
-
-  int colour_filter(const gchar * filename, GPatternSpec * colourglob);
+  gint KeyReleaseEvent(GdkEventKey * event);
+  gint KeyPressEvent(GdkEventKey * event);
 
   ///
   /// Return an array of allowed values for a string parameter.
@@ -140,8 +128,6 @@ public:
   ///
   void UserLogNewTrial();
 
-  void WriteTrainFile(const std::string &strNewText);
-
   void ExternalKeyDown(int iKeyVal);
   void ExternalKeyUp(int iKeyVal);
   
@@ -152,10 +138,13 @@ private:
   virtual void ScanAlphabetFiles(std::vector<std::string> &vFileList);
   virtual void ScanColourFiles(std::vector<std::string> &vFileList);
   virtual void SetupPaths();
+  virtual void CreateLocalFactories();
   virtual void SetupUI();
   virtual void CreateSettingsStore();
-  virtual void HandleEvent(CEvent * pEvent);
   virtual int GetFileSize(const std::string &strFileName);
+  virtual void WriteTrainFile(const std::string &strNewText);
+  virtual void StartTimer();
+  virtual void ShutdownTimer();
 
   ///
   /// Pass events coming from the core to the appropriate handler.
@@ -172,27 +161,13 @@ private:
 
   GtkWidget *m_pVBox;
   GtkWidget *m_pCanvas;
-  GtkWidget *m_pSpeedHScale;
-  GtkWidget *m_pSpeedFrame;
-
-  GtkWidget *m_pStatusBar;
-
-  GtkWidget *m_pSpin;
-  GtkWidget *m_pCombo;
-  GtkWidget *m_pStatusLabel;
-
 
   ///
   /// Abstracted input device object for mouse input.
   ///
 
   CDasherMouseInput *m_pMouseInput;
-
-  ///
-  /// Abstracted input device object for TCP/IP socket input.
-  ///
-
-  CSocketInput *m_pSocketInput;
+  CDasher1DMouseInput *m_p1DMouseInput;
 
   ///
   /// Cache of Pango layouts
@@ -217,9 +192,6 @@ private:
   ///
 
   CKeyboardHelper *m_pKeyboardHelper;
-
-  int m_iComboCount;
-
 };
 
 #endif
